@@ -7,3 +7,7 @@ dplyr::mutate
 #' @importFrom dplyr group_by
 #' @export
 dplyr::group_by
+#' @importFrom ggsignif geom_signif
+#' @export
+ggsignif::geom_signif
+
